@@ -17,6 +17,7 @@
  */
 
 #include "mutt.h"
+#include "mailbox.h"
 
 #include <limits.h>
 #include <string.h>
@@ -157,7 +158,7 @@ int mutt_parse_hook (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 #ifdef M_PGPHOOK
     if ((rc = REGCOMP (rx, NONULL(pattern.data), ((data & (M_PGPHOOK|M_CHARSETHOOK)) ? REG_ICASE : 0))) != 0)
 #else
-    if ((rc = REGCOMP (rx, NONULL(pattern.data), (data & M_CHARSETHOOK) ? REG_ICASE : 0)) != 0)
+    if ((rc = REGCOMP (rx, NONULL(pattern.data), (data & (M_CHARSETHOOK|M_ICONVHOOK)) ? REG_ICASE : 0)) != 0)
 #endif /* HAVE_PGP */
     {
       regerror (rc, rx, err->data, err->dsize);
@@ -385,7 +386,7 @@ void mutt_select_fcc (char *path, size_t pathlen, HEADER *hdr)
       adr = env->to ? env->to : (env->cc ? env->cc : env->bcc);
       mutt_safe_path (buf, sizeof (buf), adr);
       snprintf (path, pathlen, "%s/%s", NONULL (Maildir), buf);
-      if (!option (OPTFORCENAME) && access (path, W_OK) != 0)
+      if (!option (OPTFORCENAME) && mx_access (path, W_OK) != 0)
 	strfcpy (path, NONULL (Outbox), pathlen);
     }
     else
@@ -412,6 +413,11 @@ char *mutt_charset_hook (const char *chs)
   return _mutt_string_hook (chs, M_CHARSETHOOK);
 }
 
+char *mutt_iconv_hook (const char *chs)
+{
+  return _mutt_string_hook (chs, M_ICONVHOOK);
+}
+
 #ifdef HAVE_PGP
 char *mutt_pgp_hook (ADDRESS *adr)
 {
