@@ -382,6 +382,9 @@ enum
   OPTUSE8BITMIME,
   OPTUSEDOMAIN,
   OPTUSEFROM,
+#ifdef HAVE_GETADDRINFO
+  OPTUSEIPV6,
+#endif
   OPTWAITKEY,
   OPTWEED,
   OPTWRAP,
