@@ -1473,18 +1473,16 @@ static BODY *pgp_encrypt_message (BODY *a, char *keylist, int sign)
   t->parts->type = TYPEAPPLICATION;
   t->parts->subtype = safe_strdup ("pgp-encrypted");
   t->parts->encoding = ENC7BIT;
-  t->parts->use_disp = 1;
-  t->parts->disposition = DISPINLINE;
-  t->parts->d_filename = safe_strdup ("msg.asc"); /* non pgp/mime can save */
 
   t->parts->next = mutt_new_body ();
   t->parts->next->type = TYPEAPPLICATION;
   t->parts->next->subtype = safe_strdup ("octet-stream");
   t->parts->next->encoding = ENC7BIT;
   t->parts->next->filename = safe_strdup (tempfile);
-  t->parts->next->use_disp = 0;
+  t->parts->next->use_disp = 1;
   t->parts->next->disposition = DISPINLINE;
   t->parts->next->unlink = 1; /* delete after sending the message */
+  t->parts->next->d_filename = safe_strdup ("msg.asc"); /* non pgp/mime can save */
 
   return (t);
 }
