@@ -15,7 +15,8 @@
  * 
  *     You should have received a copy of the GNU General Public
  *     License along with this program; if not, write to the Free
- *     Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ *     Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *     Boston, MA  02111, USA.
  */
 
 /* Generally useful, pgp-related functions. */
@@ -51,44 +52,6 @@ const char *pgp_pkalgbytype (unsigned char type)
 }
 
 
-static struct
-{
-  char *pkalg;
-  char *micalg;
-}
-pktomic[] =
-{
-  {
-    "RSA", "pgp-md5"
-  }
-  ,
-  {
-    "ElG", "pgp-rmd160"
-  }
-  ,
-  {
-    "DSA", "pgp-sha1"
-  }
-  ,
-  {
-    NULL, "x-unknown"
-  }
-};
-
-
-const char *pgp_pkalg_to_mic (const char *alg)
-{
-  int i;
-
-  for (i = 0; pktomic[i].pkalg; i++)
-  {
-    if (!mutt_strcasecmp (pktomic[i].pkalg, alg))
-      break;
-  }
-
-  return pktomic[i].micalg;
-}
-
 
 /* unused */
 
