@@ -279,6 +279,8 @@ static void process_user_header (ENVELOPE *env)
       rfc822_free_address (&env->reply_to);
       env->reply_to = rfc822_parse_adrlist (env->reply_to, uh->data + 9);
     }
+    else if (mutt_strncasecmp ("message-id:", uh->data, 11) == 0)
+      mutt_str_replace (&env->message_id, uh->data + 11);
     else if (mutt_strncasecmp ("to:", uh->data, 3) != 0 &&
 	     mutt_strncasecmp ("cc:", uh->data, 3) != 0 &&
 	     mutt_strncasecmp ("bcc:", uh->data, 4) != 0 &&
